<?php
/**
 * Plugin Name: GPP About You Widget
 * Plugin URI: http://graphpaperpress.com/plugins/gpp-about-you-widget/
 * Description: A widget that introduces you to the world.
 * Version: 1.0
 * Author: Thad Allender
 * Author URI: http://graphpaperpress.com
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

/**
 * Add function to widgets_init that'll load our widget.
 * @since 1.0
 */
add_action( 'widgets_init', 'about_you_load_widgets' );

/**
 * Register our widget.
 * 'About_You_Widget' is the widget class used below.
 *
 * @since 1.0
 */
function about_you_load_widgets() {
	register_widget( 'About_You_Widget' );
}

/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 1.0
 */
class About_You_Widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function About_You_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'About You', 'description' => __('A widget that introduces you to the world.', 'about_you') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'about-you-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'about-you-widget', __('About You', 'about_you'), $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$photo = $instance['photo'];
		$about = $instance['about'];
		$email = $instance['email'];
		$phone = $instance['phone'];
		$link = $instance['link'];

		/* Before widget (defined by themes). */
		echo $before_widget;
		
		echo '<div class="about_you_widget clearfix">';

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . 'About ' . $title . $after_title;
			
		/* If there is a photo, show it. */
		if ( $photo )
			echo '<img src="'.$photo.'" alt="'.$title.'" class="alignleft" />';
			
		/* If there is about text, show it. */
		if ( $about )
			echo $about;
			
		/* If email or phone or link. */
		if ( $email || $phone || $link)
			echo '<ul>';

		/* If show email was selected, display the user's email. */
		if ( $email )
			printf( '<li class="email"><a href="mailto:' . __('%1$s', 'about_you.') . '" title="Email ' . __('%2$s', 'about_you.') . '">' . __('%1$s', 'about_you.') . '</a></li>', $email, $title );
			
		/* If show phone was selected, display the user's phone. */
		if ( $phone )
			printf( '<li class="phone">' . __('%1$s', 'about_you.') . '</li>', $phone );

		/* If link, show link */
		if ( $link )
			printf( '<li class="link"><a href="' . __('%1$s', 'about_you.') . '" title="' . __('%2$s', 'about_you.') . '">' . __('%1$s', 'about_you.') . '</a></li>', $link, $title );
			
		/* If email or phone or link. */
		if ( $email || $phone || $link )
				echo '</ul>';
		
		echo '</div><!-- .about_you_widget -->';

		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['photo'] = strip_tags( $new_instance['photo'] );
		$instance['email'] = strip_tags( $new_instance['email'] );
		$instance['phone'] = strip_tags( $new_instance['phone'] );
		$instance['link'] = strip_tags( $new_instance['link'] );
		
		/* No need to strip tags for show_email, show_phone. */
		$instance['about'] = $new_instance['about'];
		
		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('', 'about_you'), 'photo' => 'http://', 'about' => '', 'email' => '', 'phone' => '', 'link' => 'http://' );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Your Name:', 'about_you'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>

		<!-- Your Photo: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'photo' ); ?>"><?php _e('Your Photo:', 'about_you'); ?></label>
			<?php
				$photo = $instance['photo'];
				if ( $photo ) { ?>
					<p><img src="<?php echo $instance['photo']; ?>" width="50px" height="auto" /></p>
			<?php } ?>
			<input id="<?php echo $this->get_field_id( 'photo' ); ?>" name="<?php echo $this->get_field_name( 'photo' ); ?>" value="<?php echo $instance['photo']; ?>" class="widefat" /><br />
			<span class="description small"><a href="media-new.php">Upload a photo</a> and paste the URL to it here.  Crop and size accordingly before uploading.</span>
		</p>
		
		<!-- About: Text Area -->
		<p>
			<label for="<?php echo $this->get_field_id( 'about' ); ?>"><?php _e('About You:', 'about_you'); ?></label> 
			<textarea rows="6" class="widefat" id="<?php echo $this->get_field_id( 'about' ); ?>" name="<?php echo $this->get_field_name( 'about' ); ?>"><?php echo $instance['about']; ?></textarea>
		</p>
		
		<!-- Email: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'email' ); ?>"><?php _e('Email:', 'about_you'); ?></label> 
			<input id="<?php echo $this->get_field_id( 'email' ); ?>" name="<?php echo $this->get_field_name( 'email' ); ?>" value="<?php echo $instance['email']; ?>" class="widefat" />
		</p>

		<!-- Phone: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'phone' ); ?>"><?php _e('Phone:', 'about_you'); ?></label> 
			<input id="<?php echo $this->get_field_id( 'phone' ); ?>" name="<?php echo $this->get_field_name( 'phone' ); ?>" value="<?php echo $instance['phone']; ?>" class="widefat" />
		</p>
		
		<!-- Link: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'link' ); ?>"><?php _e('Additional info:', 'about_you'); ?></label> 
			<input id="<?php echo $this->get_field_id( 'link' ); ?>" name="<?php echo $this->get_field_name( 'link' ); ?>" value="<?php echo $instance['link']; ?>" class="widefat" />
		</p>
		
	<?php
	}
}

?>